@@ -1,5 +1,5 @@
 /* GtkDatabox - An extension to the gtk+ library
- * Copyright (C) 1998 - 2005  Dr. Roland Bock
+ * Copyright (C) 1998 - 2007  Dr. Roland Bock
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -67,9 +67,8 @@ create_grid (void)
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
 
    /* Create a GtkDatabox widget along with scrollbars and rulers */
-   gtk_databox_create_box_with_scrollbars_and_rulers (&box, &table, 
-                                                      TRUE, TRUE,
-                                                      TRUE, TRUE);
+   gtk_databox_create_box_with_scrollbars_and_rulers (&box, &table,
+						      TRUE, TRUE, TRUE, TRUE);
    gtk_box_pack_start (GTK_BOX (box1), table, TRUE, TRUE, 0);
 
    color.red = 0;
@@ -91,7 +90,7 @@ create_grid (void)
 
    graph = gtk_databox_points_new (POINTS, X, Y, &color, 3);
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
-   
+
    Y = g_new0 (gfloat, POINTS);
 
    for (i = 0; i < POINTS; i++)
@@ -121,7 +120,7 @@ create_grid (void)
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
    gtk_databox_auto_rescale (GTK_DATABOX (box), 0.05);
-         
+
    separator = gtk_hseparator_new ();
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, TRUE, 0);
 
